@@ -40,7 +40,9 @@
 
 /*** DOCUMENTATION
 	<application name="ControlPlayback" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.0.0</version>
+		</since>
 		<synopsis>
 			Play a file with fast forward and rewind.
 		</synopsis>
