@@ -332,6 +332,10 @@ struct dahdi_pvt {
 	 * \note Set from the "callwaiting" value read in from chan_dahdi.conf
 	 */
 	unsigned int permcallwaiting:1;
+	/*!
+	 * \brief TRUE if Call Waiting Deluxe options should be available
+	 */
+	unsigned int callwaitingdeluxe:1;
 	/*!
 	 * \brief TRUE if the outgoing caller ID is blocked/restricted/hidden.
 	 * \note Set from the "hidecallerid" value read in from chan_dahdi.conf
