@@ -38,7 +38,9 @@
 
 /*** DOCUMENTATION
 	<function name="ISNULL" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Check if a value is NULL.
 		</synopsis>
@@ -50,7 +52,9 @@
 		</description>
 	</function>
 	<function name="SET" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			SET assigns a value to a channel variable.
 		</synopsis>
@@ -62,7 +66,9 @@
 		</description>
 	</function>
 	<function name="EXISTS" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Test the existence of a value.
 		</synopsis>
@@ -74,7 +80,9 @@
 		</description>
 	</function>
 	<function name="IF" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Check for an expression.
 		</synopsis>
@@ -90,7 +98,9 @@
 		</description>
 	</function>
 	<function name="IFTIME" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Temporal Conditional.
 		</synopsis>
@@ -106,7 +116,9 @@
 		</description>
 	</function>
 	<function name="IMPORT" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Retrieve the value of a variable from another channel.
 		</synopsis>
@@ -118,7 +130,11 @@
 		</description>
 	</function>
 	<function name="DELETE" language="en_US">
-		<since><version>18.21.0</version><version>20.6.0</version><version>21.1.0</version></since>
+		<since>
+			<version>18.21.0</version>
+			<version>20.6.0</version>
+			<version>21.1.0</version>
+		</since>
 		<synopsis>
 			Deletes a specified channel variable.
 		</synopsis>
@@ -136,7 +152,11 @@
 		</see-also>
 	</function>
 	<function name="VARIABLE_EXISTS" language="en_US">
-		<since><version>18.21.0</version><version>20.6.0</version><version>21.1.0</version></since>
+		<since>
+			<version>18.21.0</version>
+			<version>20.6.0</version>
+			<version>21.1.0</version>
+		</since>
 		<synopsis>
 			Check if a dialplan variable exists or not.
 		</synopsis>
