@@ -46,7 +46,9 @@
 
 /*** DOCUMENTATION
 	<function name="PJSIP_ENDPOINT" language="en_US">
-		<since><version>12.0.0</version></since>
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Get information about a PJSIP endpoint
 		</synopsis>
