@@ -308,14 +308,23 @@ static struct ast_frame *audiohook_read_frame_both(struct ast_audiohook *audioho
 	 *    2 * samples) according to actual needs, for example, setting it to (ast_tvdiff_ms(ast_tvnow(),
 	 *    audiohook->write_time) < (samples/8)*4) && (ast_slinfactory_available(&audiohook->read_factory)
 	 *    < 4 * samples).
+	 *
+	 *    Update:
+	 *       Increased time and sample thresholds allow for better handling of asymmetric streams
+	 *       (e.g., mixed codecs like alaw and G.722) and high RTT conditions.
+	 *       This avoids premature frame reads when one direction is delayed, which can cause
+	 *       audio tearing or broken recordings.
+	 *       Specifically addresses issues with MixMonitor when recording directly on a channel
+	 *       that is part of a bridge with different sample rates or codecs.
+	 *       A slight overrun in recording duration is acceptable in exchange for audio stability.
 	 */
-	if (usable_read && !usable_write && (ast_tvdiff_ms(ast_tvnow(), audiohook->write_time) < (samples/8)*2) && (ast_slinfactory_available(&audiohook->read_factory) < 2 * samples)) {
+	if (usable_read && !usable_write && (ast_tvdiff_ms(ast_tvnow(), audiohook->write_time) < (samples/8)*4) && (ast_slinfactory_available(&audiohook->read_factory) < 4 * samples)) {
 		ast_debug(3, "Write factory %p was pretty quick last time, waiting for them.\n", &audiohook->write_factory);
 		return NULL;
 	}
 
 	/* As shown in the above comment. */
-	if (usable_write && !usable_read && (ast_tvdiff_ms(ast_tvnow(), audiohook->read_time) < (samples/8)*2) && (ast_slinfactory_available(&audiohook->write_factory) < 2 * samples)) {
+	if (usable_write && !usable_read && (ast_tvdiff_ms(ast_tvnow(), audiohook->read_time) < (samples/8)*4) && (ast_slinfactory_available(&audiohook->write_factory) < 4 * samples)) {
 		ast_debug(3, "Read factory %p was pretty quick last time, waiting for them.\n", &audiohook->read_factory);
 		return NULL;
 	}
@@ -496,7 +505,7 @@ static void audiohook_list_set_samplerate_compatibility(struct ast_audiohook_lis
 	 * at that level when it should be lower, and with no way to lower it since any
 	 * rate compared against it would be lower.
 	 *
-	 * By setting it back to the lowest rate it can recalulate the new highest rate.
+	 * By setting it back to the lowest rate it can recalculate the new highest rate.
 	 */
 	audiohook_list->list_internal_samp_rate = DEFAULT_INTERNAL_SAMPLE_RATE;
 
@@ -1210,8 +1219,8 @@ int ast_channel_audiohook_count_by_source_running(struct ast_channel *chan, cons
 /*! \brief Audiohook volume adjustment structure */
 struct audiohook_volume {
 	struct ast_audiohook audiohook; /*!< Audiohook attached to the channel */
-	int read_adjustment;            /*!< Value to adjust frames read from the channel by */
-	int write_adjustment;           /*!< Value to adjust frames written to the channel by */
+	float read_adjustment;            /*!< Value to adjust frames read from the channel by */
+	float write_adjustment;           /*!< Value to adjust frames written to the channel by */
 };
 
 /*! \brief Callback used to destroy the audiohook volume datastore
@@ -1248,14 +1257,14 @@ static int audiohook_volume_callback(struct ast_audiohook *audiohook, struct ast
 {
 	struct ast_datastore *datastore = NULL;
 	struct audiohook_volume *audiohook_volume = NULL;
-	int *gain = NULL;
+	float *gain = NULL;
 
 	/* If the audiohook is shutting down don't even bother */
 	if (audiohook->status == AST_AUDIOHOOK_STATUS_DONE) {
 		return 0;
 	}
 
-	/* Try to find the datastore containg adjustment information, if we can't just bail out */
+	/* Try to find the datastore containing adjustment information, if we can't just bail out */
 	if (!(datastore = ast_channel_datastore_find(chan, &audiohook_volume_datastore, NULL))) {
 		return 0;
 	}
@@ -1271,7 +1280,7 @@ static int audiohook_volume_callback(struct ast_audiohook *audiohook, struct ast
 
 	/* If an adjustment value is present modify the frame */
 	if (gain && *gain) {
-		ast_frame_adjust_volume(frame, *gain);
+		ast_frame_adjust_volume_float(frame, *gain);
 	}
 
 	return 0;
@@ -1319,6 +1328,11 @@ static struct audiohook_volume *audiohook_volume_get(struct ast_channel *chan, i
 }
 
 int ast_audiohook_volume_set(struct ast_channel *chan, enum ast_audiohook_direction direction, int volume)
+{
+	return ast_audiohook_volume_adjust_float(chan, direction, (float) volume);
+}
+
+int ast_audiohook_volume_set_float(struct ast_channel *chan, enum ast_audiohook_direction direction, float volume)
 {
 	struct audiohook_volume *audiohook_volume = NULL;
 
@@ -1339,9 +1353,14 @@ int ast_audiohook_volume_set(struct ast_channel *chan, enum ast_audiohook_direct
 }
 
 int ast_audiohook_volume_get(struct ast_channel *chan, enum ast_audiohook_direction direction)
+{
+	return (int) ast_audiohook_volume_get_float(chan, direction);
+}
+
+float ast_audiohook_volume_get_float(struct ast_channel *chan, enum ast_audiohook_direction direction)
 {
 	struct audiohook_volume *audiohook_volume = NULL;
-	int adjustment = 0;
+	float adjustment = 0;
 
 	/* Attempt to find the audiohook volume information, but do not create it as we only want to look at the values */
 	if (!(audiohook_volume = audiohook_volume_get(chan, 0))) {
@@ -1359,6 +1378,11 @@ int ast_audiohook_volume_get(struct ast_channel *chan, enum ast_audiohook_direct
 }
 
 int ast_audiohook_volume_adjust(struct ast_channel *chan, enum ast_audiohook_direction direction, int volume)
+{
+	return ast_audiohook_volume_adjust_float(chan, direction, (float) volume);
+}
+
+int ast_audiohook_volume_adjust_float(struct ast_channel *chan, enum ast_audiohook_direction direction, float volume)
 {
 	struct audiohook_volume *audiohook_volume = NULL;
 
