@@ -42,7 +42,9 @@
 
 /*** DOCUMENTATION
 	<application name="Answer" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Answer a channel if ringing.
 		</synopsis>
@@ -73,7 +75,9 @@
 		</see-also>
 	</application>
 	<application name="BackGround" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Play an audio file while waiting for digits of an extension to go to.
 		</synopsis>
@@ -140,7 +144,9 @@
 		</see-also>
 	</application>
 	<application name="Busy" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Indicate the Busy condition.
 		</synopsis>
@@ -161,7 +167,9 @@
 		</see-also>
 	</application>
 	<application name="Congestion" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Indicate the Congestion condition.
 		</synopsis>
@@ -182,7 +190,9 @@
 		</see-also>
 	</application>
 	<application name="ExecIfTime" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Conditional application execution based on the current time.
 		</synopsis>
@@ -210,14 +220,16 @@
 		</see-also>
 	</application>
 	<application name="Goto" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Jump to a particular priority, extension, or context.
 		</synopsis>
 		<syntax>
-			<parameter name="context" />
-			<parameter name="extensions" />
-			<parameter name="priority" required="true" />
+			<parameter name="context" documentationtype="dialplan_context" />
+			<parameter name="extension" documentationtype="dialplan_extension" />
+			<parameter name="priority" documentationtype="dialplan_priority" required="true" />
 		</syntax>
 		<description>
 			<para>This application will set the current context, extension, and priority in the channel structure.
@@ -243,7 +255,9 @@
 		</see-also>
 	</application>
 	<application name="GotoIf" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Conditional goto.
 		</synopsis>
@@ -282,7 +296,9 @@
 		</see-also>
 	</application>
 	<application name="GotoIfTime" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Conditional Goto based on the current time.
 		</synopsis>
@@ -324,7 +340,9 @@
 		</see-also>
 	</application>
 	<application name="Hangup" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Hang up the calling channel.
 		</synopsis>
@@ -344,7 +362,9 @@
 		</see-also>
 	</application>
 	<application name="Incomplete" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Returns AST_PBX_INCOMPLETE value.
 		</synopsis>
@@ -362,7 +382,9 @@
 		</description>
 	</application>
 	<application name="NoOp" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Do Nothing (No Operation).
 		</synopsis>
@@ -381,7 +403,9 @@
 		</see-also>
 	</application>
 	<application name="Proceeding" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Indicate proceeding.
 		</synopsis>
@@ -391,7 +415,9 @@
 		</description>
 	</application>
 	<application name="Progress" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Indicate progress.
 		</synopsis>
@@ -407,7 +433,9 @@
 		</see-also>
 	</application>
 	<application name="RaiseException" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Handle an exceptional condition.
 		</synopsis>
@@ -423,7 +451,9 @@
 		</see-also>
 	</application>
 	<application name="Ringing" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Indicate ringing tone.
 		</synopsis>
@@ -439,7 +469,9 @@
 		</see-also>
 	</application>
 	<application name="SayAlpha" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Say Alpha.
 		</synopsis>
@@ -464,7 +496,9 @@
 		</see-also>
 	</application>
 	<application name="SayAlphaCase" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Say Alpha.
 		</synopsis>
@@ -509,7 +543,9 @@
 		</see-also>
 	</application>
 	<application name="SayDigits" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Say Digits.
 		</synopsis>
@@ -534,7 +570,10 @@
 		</see-also>
 	</application>
 	<application name="SayMoney" language="en_US">
-		<since><version>16.21.0</version><version>18.7.0</version></since>
+		<since>
+			<version>16.21.0</version>
+			<version>18.7.0</version>
+		</since>
 		<synopsis>
 			Say Money.
 		</synopsis>
@@ -558,7 +597,9 @@
 		</see-also>
 	</application>
 	<application name="SayNumber" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Say Number.
 		</synopsis>
@@ -584,7 +625,10 @@
 		</see-also>
 	</application>
 	<application name="SayOrdinal" language="en_US">
-		<since><version>16.21.0</version><version>18.7.0</version></since>
+		<since>
+			<version>16.21.0</version>
+			<version>18.7.0</version>
+		</since>
 		<synopsis>
 			Say Ordinal Number.
 		</synopsis>
@@ -612,7 +656,9 @@
 		</see-also>
 	</application>
 	<application name="SayPhonetic" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Say Phonetic.
 		</synopsis>
@@ -635,7 +681,9 @@
 		</see-also>
 	</application>
 	<application name="Wait" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Waits for some time.
 		</synopsis>
@@ -650,7 +698,9 @@
 		</description>
 	</application>
 	<application name="WaitDigit" language="en_US">
-		<since><version>15.0.0</version></since>
+		<since>
+			<version>15.0.0</version>
+		</since>
 		<synopsis>
 			Waits for a digit to be entered.
 		</synopsis>
@@ -687,7 +737,9 @@
 		</see-also>
 	</application>
 	<application name="WaitExten" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Waits for an extension to be entered.
 		</synopsis>
