@@ -45,7 +45,9 @@
 
 /*** DOCUMENTATION
 	<application name="Set" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Set channel variable or function value.
 		</synopsis>
@@ -76,7 +78,9 @@
 		</see-also>
 	</application>
 	<application name="MSet" language="en_US">
-		<since><version>13.8.0</version></since>
+		<since>
+			<version>13.8.0</version>
+		</since>
 		<synopsis>
 			Set channel variable(s) or function value(s).
 		</synopsis>
