@@ -363,7 +363,7 @@ int ast_test_capture_command(struct ast_test_capture *capture, const char *file,
 	}
 
 	if (pipe(fd2) == -1) {
-		ast_log(LOG_ERROR, "Couldn't open stdout pipe: %s\n", strerror(errno));
+		ast_log(LOG_ERROR, "Couldn't open stderr pipe: %s\n", strerror(errno));
 		goto cleanup;
 	}
 
@@ -472,7 +472,10 @@ int ast_test_capture_command(struct ast_test_capture *capture, const char *file,
 			 */
 			n = select(nfds, &readfds, &writefds, NULL, NULL);
 
-			if (FD_ISSET(fd0[1], &writefds)) {
+			/* A version of FD_ISSET() that is tolerant of -1 file descriptors */
+#define SAFE_FD_ISSET(fd, setptr) ((fd) != -1 && FD_ISSET((fd), setptr))
+
+			if (SAFE_FD_ISSET(fd0[1], &writefds)) {
 				n = write(fd0[1], data, datalen);
 				if (n > 0) {
 					data += n;
@@ -485,7 +488,7 @@ int ast_test_capture_command(struct ast_test_capture *capture, const char *file,
 				}
 			}
 
-			if (FD_ISSET(fd1[0], &readfds)) {
+			if (SAFE_FD_ISSET(fd1[0], &readfds)) {
 				n = read(fd1[0], buf, sizeof(buf));
 				if (n > 0) {
 					fwrite(buf, sizeof(char), n, out);
@@ -494,7 +497,7 @@ int ast_test_capture_command(struct ast_test_capture *capture, const char *file,
 				}
 			}
 
-			if (FD_ISSET(fd2[0], &readfds)) {
+			if (SAFE_FD_ISSET(fd2[0], &readfds)) {
 				n = read(fd2[0], buf, sizeof(buf));
 				if (n > 0) {
 					fwrite(buf, sizeof(char), n, err);
@@ -502,6 +505,8 @@ int ast_test_capture_command(struct ast_test_capture *capture, const char *file,
 					zclose(fd2[0]);
 				}
 			}
+
+#undef SAFE_FD_ISSET
 		}
 		status = 1;
 
@@ -710,8 +715,8 @@ static int test_execute_multiple(const char *name, const char *category, struct
 		/* update total counts as well during this iteration
 		 * even if the current test did not execute this time */
 		last_results.total_time += test->time;
-		last_results.total_tests++;
 		if (test->state != AST_TEST_NOT_RUN) {
+			last_results.total_tests++;
 			if (test->state == AST_TEST_PASS) {
 				last_results.total_passed++;
 			} else {
@@ -788,10 +793,10 @@ static int test_generate_results(const char *name, const char *category, const c
 		 */
 		fprintf(f_xml, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
 		fprintf(f_xml, "<testsuites>\n");
-		fprintf(f_xml, "\t<testsuite errors=\"0\" time=\"%u.%u\" tests=\"%u\" "
+		fprintf(f_xml, "\t<testsuite errors=\"0\" time=\"%u.%u\" tests=\"%u\" failures=\"%u\" "
 				"name=\"AsteriskUnitTests\">\n",
 				last_results.total_time / 1000, last_results.total_time % 1000,
-				last_results.total_tests);
+				last_results.total_tests, last_results.total_failed);
 		fprintf(f_xml, "\t\t<properties>\n");
 		fprintf(f_xml, "\t\t\t<property name=\"version\" value=\"%s\"/>\n", ast_get_version());
 		fprintf(f_xml, "\t\t</properties>\n");
@@ -1008,6 +1013,11 @@ static struct ast_test *test_alloc(ast_test_cb_t *cb)
 	return test;
 }
 
+struct ast_cli_args *ast_test_get_cli_args(struct ast_test *test)
+{
+	return test->cli;
+}
+
 static char *complete_test_category(const char *word)
 {
 	int wordlen = strlen(word);
@@ -1110,18 +1120,24 @@ static char *test_cli_show_registered(struct ast_cli_entry *e, int cmd, struct a
 static char *test_cli_execute_registered(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
 {
 	static const char * const option1[] = { "all", "category", NULL };
-	static const char * const option2[] = { "name", NULL };
+	static const char * const option2[] = { "name", "options", NULL };
+	static const char * const option3[] = { "options", NULL };
 
 	switch (cmd) {
 	case CLI_INIT:
 		e->command = "test execute";
 		e->usage =
-			"Usage: test execute can be used in three ways.\n"
+			"Usage: test execute can be used in several ways.\n"
 			"       1. 'test execute all' runs all registered tests\n"
 			"       2. 'test execute category [test category]' runs all tests in the given\n"
 			"          category.\n"
-			"       3. 'test execute category [test category] name [test name]' runs all\n"
-			"           tests in a given category matching a given name\n";
+			"       3. 'test execute category [test category] options [test option]...' runs all\n"
+			"           tests in the given category with options supplied to each test\n"
+			"       4. 'test execute category [test category] name [test name]' runs all\n"
+			"           tests in a given category matching a given name\n"
+			"       5. 'test execute category [test category] name [test name] options [test option]...' runs all\n"
+			"           tests in a given category matching a given name with the specified options\n"
+			;
 		return NULL;
 	case CLI_GENERATE:
 		if (a->pos == 2) {
@@ -1133,13 +1149,19 @@ static char *test_cli_execute_registered(struct ast_cli_entry *e, int cmd, struc
 		if (a->pos == 4) {
 			return ast_cli_complete(a->word, option2, -1);
 		}
-		if (a->pos == 5) {
+		if (a->pos == 5 && !strcasecmp(a->argv[4], "name")) {
 			return complete_test_name(a->word, a->argv[3]);
 		}
+		if (a->pos == 5 && !strcasecmp(a->argv[4], "options")) {
+			return NULL;
+		}
+		if (a->pos == 6 && !strcasecmp(a->argv[4], "name")) {
+			return ast_cli_complete(a->word, option3, -1);
+		}
 		return NULL;
 	case CLI_HANDLER:
 
-		if (a->argc < 3|| a->argc > 6) {
+		if (a->argc < 3) {
 			return CLI_SHOWUSAGE;
 		}
 
@@ -1149,9 +1171,15 @@ static char *test_cli_execute_registered(struct ast_cli_entry *e, int cmd, struc
 		} else if (a->argc == 4) { /* run only tests within a category */
 			ast_cli(a->fd, "Running all available tests matching category %s\n\n", a->argv[3]);
 			test_execute_multiple(NULL, a->argv[3], a);
-		} else if (a->argc == 6) { /* run only a single test matching the category and name */
+		} else if (a->argc >= 6 && !strcasecmp(a->argv[4], "options")) { /* run only tests within a category */
+			ast_cli(a->fd, "Running all available tests matching category %s with options\n\n", a->argv[3]);
+			test_execute_multiple(NULL, a->argv[3], a);
+		} else if (a->argc == 6 && !strcasecmp(a->argv[4], "name")) { /* run only a single test matching the category and name */
 			ast_cli(a->fd, "Running all available tests matching category %s and name %s\n\n", a->argv[3], a->argv[5]);
 			test_execute_multiple(a->argv[5], a->argv[3], a);
+		} else if (a->argc > 7) { /* run only a single test matching the category and name */
+			ast_cli(a->fd, "Running all available tests matching category %s and name %s with options\n\n", a->argv[3], a->argv[5]);
+			test_execute_multiple(a->argv[5], a->argv[3], a);
 		} else {
 			return CLI_SHOWUSAGE;
 		}
