@@ -36,10 +36,10 @@
 #include <unistd.h>
 #if defined(__APPLE__)
 #include <mach/mach.h>
+#elif defined(__FreeBSD__)
+#include <sys/thr.h>
 #elif defined(__NetBSD__)
 #include <lwp.h>
-#elif defined(HAVE_SYS_THR_H)
-#include <sys/thr.h>
 #endif
 
 #include "asterisk/network.h"
@@ -1841,7 +1841,8 @@ char *ast_strsep(char **iss, const char sep, uint32_t flags)
 	char stack[8];
 
 	if (ast_strlen_zero(st)) {
-		return NULL;
+		*iss = NULL;
+		return st;
 	}
 
 	memset(stack, 0, sizeof(stack));
@@ -1905,7 +1906,8 @@ char *ast_strsep_quoted(char **iss, const char sep, const char quote, uint32_t f
 	const char qstr[] = { quote };
 
 	if (ast_strlen_zero(st)) {
-		return NULL;
+		*iss = NULL;
+		return st;
 	}
 
 	memset(stack, 0, sizeof(stack));
@@ -2629,7 +2631,7 @@ int ast_utils_init(void)
 /*!
  *\brief Parse digest authorization header.
  *\return Returns -1 if we have no auth or something wrong with digest.
- *\note	This function may be used for Digest request and responce header.
+ *\note	This function may be used for Digest request and response header.
  * request arg is set to nonzero, if we parse Digest Request.
  * pedantic arg can be set to nonzero if we need to do addition Digest check.
  */
@@ -2757,9 +2759,9 @@ int ast_get_tid(void)
 #elif defined(__APPLE__)
 	ret = mach_thread_self();
 	mach_port_deallocate(mach_task_self(), ret);
-#elif defined(__FreeBSD__) && defined(HAVE_SYS_THR_H)
+#elif defined(__FreeBSD__)
 	long lwpid;
-	thr_self(&lwpid); /* available since sys/thr.h creation 2003 */
+	thr_self(&lwpid);
 	ret = lwpid;
 #elif defined(__NetBSD__)
 	ret = _lwp_self();
