@@ -947,13 +947,21 @@ void ast_ari_bridges_create(struct ast_variable *headers,
 	struct ast_ari_bridges_create_args *args,
 	struct ast_ari_response *response)
 {
-	RAII_VAR(struct ast_bridge *, bridge, stasis_app_bridge_create(args->type, args->name, args->bridge_id), ao2_cleanup);
+	RAII_VAR(struct ast_bridge *, bridge, NULL, ao2_cleanup);
 	RAII_VAR(struct ast_bridge_snapshot *, snapshot, NULL, ao2_cleanup);
 
+	if (ast_bridge_topic_exists(args->bridge_id)) {
+		ast_ari_response_error(
+			response, 409, "Conflict",
+			"Bridge with id '%s' already exists", args->bridge_id);
+		return;
+	}
+
+	bridge = stasis_app_bridge_create(args->type, args->name, args->bridge_id);
 	if (!bridge) {
 		ast_ari_response_error(
 			response, 500, "Internal Error",
-			"Unable to create bridge");
+			"Unable to create bridge. Possible duplicate bridge id '%s'", args->bridge_id);
 		return;
 	}
 
@@ -976,26 +984,13 @@ void ast_ari_bridges_create_with_id(struct ast_variable *headers,
 	struct ast_ari_bridges_create_with_id_args *args,
 	struct ast_ari_response *response)
 {
-	RAII_VAR(struct ast_bridge *, bridge, find_bridge(response, args->bridge_id), ao2_cleanup);
+	RAII_VAR(struct ast_bridge *, bridge, NULL, ao2_cleanup);
 	RAII_VAR(struct ast_bridge_snapshot *, snapshot, NULL, ao2_cleanup);
 
-	if (bridge) {
-		/* update */
-		if (!ast_strlen_zero(args->name)
-			&& strcmp(args->name, bridge->name)) {
-			ast_ari_response_error(
-				response, 500, "Internal Error",
-				"Changing bridge name is not implemented");
-			return;
-		}
-		if (!ast_strlen_zero(args->type)) {
-			ast_ari_response_error(
-				response, 500, "Internal Error",
-				"Supplying a bridge type when updating a bridge is not allowed.");
-			return;
-		}
-		ast_ari_response_ok(response,
-			ast_bridge_snapshot_to_json(snapshot, stasis_app_get_sanitizer()));
+	if (ast_bridge_topic_exists(args->bridge_id)) {
+		ast_ari_response_error(
+			response, 409, "Conflict",
+			"Bridge with id '%s' already exists", args->bridge_id);
 		return;
 	}
 
