@@ -957,7 +957,7 @@ static int res_sdp_crypto_parse_offer(struct ast_rtp_instance *rtp, struct ast_s
 		key_len_expected = AES_256_GCM_KEYSIZE_WSALT;
 #endif
 	} else {
-		ast_verb(1, "Unsupported crypto suite: %s\n", suite);
+		ast_debug(3, "Unsupported crypto suite: %s\n", suite);
 		return -1;
 	}
 
