@@ -156,13 +156,13 @@ if [ $NO_MENUSELECT -eq 0 ] ; then
 		mod_disables+=" cdr_adaptive_odbc cdr_custom cdr_manager cdr_odbc cdr_pgsql cdr_radius"
 		mod_disables+=" cdr_tds"
 		mod_disables+=" cel_odbc cel_pgsql cel_radius cel_sqlite3_custom cel_tds"
-		mod_disables+=" chan_alsa chan_console chan_mgcp chan_motif chan_rtp chan_skinny chan_unistim"
+		mod_disables+=" chan_console chan_motif chan_rtp chan_unistim"
 		mod_disables+=" func_frame_trace func_pitchshift func_speex func_volume func_dialgroup"
 		mod_disables+=" func_periodic_hook func_sprintf func_enum func_extstate func_sysinfo func_iconv"
 		mod_disables+=" func_callcompletion func_version func_rand func_sha1 func_module func_md5"
 		mod_disables+=" pbx_dundi pbx_loopback"
 		mod_disables+=" res_ael_share res_calendar res_config_ldap res_config_pgsql res_corosync"
-		mod_disables+=" res_http_post res_pktccops res_rtp_multicast res_snmp res_xmpp"
+		mod_disables+=" res_http_post res_rtp_multicast res_snmp res_xmpp"
 	fi
 
 	runner menuselect/menuselect `gen_mods disable $mod_disables` menuselect.makeopts
