@@ -29,8 +29,11 @@
 
 #include "asterisk/test.h"
 #include "asterisk/module.h"
+#include "asterisk/bridge.h"
+#include "asterisk/bridge_basic.h"
 #include "asterisk/config.h"
 #include "asterisk/res_prometheus.h"
+#include "../res/prometheus/prometheus_internal.h"
 
 #define CATEGORY "/res/prometheus/"
 
@@ -54,8 +57,6 @@ static void prometheus_metric_free_wrapper(void *ptr)
 	}
 }
 
-#define GLOBAL_USERAGENT "asterisk-libcurl-agent/1.0"
-
 static struct prometheus_general_config *config_alloc(void)
 {
 	struct prometheus_general_config *config;
@@ -84,7 +85,7 @@ static CURL *get_curl_instance(void)
 
 	curl_easy_setopt(curl, CURLOPT_NOSIGNAL, 1);
 	curl_easy_setopt(curl, CURLOPT_TIMEOUT, 180);
-	curl_easy_setopt(curl, CURLOPT_USERAGENT, GLOBAL_USERAGENT);
+	curl_easy_setopt(curl, CURLOPT_USERAGENT, AST_CURL_USER_AGENT);
 	curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt(curl, CURLOPT_URL, server_uri);
 
@@ -701,6 +702,69 @@ AST_TEST_DEFINE(config_general_core_metrics)
 	return AST_TEST_PASS;
 }
 
+static void safe_bridge_destroy(struct ast_bridge *bridge)
+{
+	if (!bridge) {
+		return;
+	}
+	ast_bridge_destroy(bridge, 0);
+}
+
+static int match_count(const char *str, const char *needle)
+{
+	int count = 0;
+
+	while ((str = strstr(str, needle))) {
+		str += strlen(needle);
+		count++;
+	}
+
+	return count;
+}
+
+AST_TEST_DEFINE(bridge_to_string)
+{
+	RAII_VAR(struct ast_bridge *, bridge1, NULL, safe_bridge_destroy);
+	RAII_VAR(struct ast_bridge *, bridge2, NULL, safe_bridge_destroy);
+	RAII_VAR(struct ast_bridge *, bridge3, NULL, safe_bridge_destroy);
+	struct ast_str *response;
+
+	switch (cmd) {
+	case TEST_INIT:
+		info->name = __func__;
+		info->category = CATEGORY;
+		info->summary = "Test producing bridge metrics";
+		info->description =
+			"This test covers checking the metrics produced by the\n"
+			"bridge support of the basic Promtheus module.";
+		return AST_TEST_NOT_RUN;
+	case TEST_EXECUTE:
+		break;
+	}
+
+	bridge1 = ast_bridge_basic_new();
+	ast_test_validate(test, bridge1 != NULL);
+
+	bridge2 = ast_bridge_base_new(AST_BRIDGE_CAPABILITY_HOLDING,
+		AST_BRIDGE_FLAG_INVISIBLE,
+		"test_res_prometheus", "test_bridge_invisible", NULL);
+
+	bridge3 = ast_bridge_basic_new();
+	ast_test_validate(test, bridge3 != NULL);
+
+	response = prometheus_scrape_to_string();
+	if (!response) {
+		return AST_TEST_FAIL;
+	}
+
+	ast_test_status_update(test, " -> Retrieved: %s\n", ast_str_buffer(response));
+	ast_test_validate(test, strstr(ast_str_buffer(response), "(null)") == NULL);
+	ast_test_validate(test, strstr(ast_str_buffer(response), "asterisk_bridges_channels_count{") != NULL);
+	ast_test_validate(test, match_count(ast_str_buffer(response), "# HELP asterisk_bridges_channels_count Number of channels in the bridge.") == 1);
+	ast_free(response);
+	return AST_TEST_PASS;
+}
+
 static int process_config(int reload)
 {
 	struct ast_config *config;
@@ -793,6 +857,8 @@ static int unload_module(void)
 	AST_TEST_UNREGISTER(config_general_basic_auth);
 	AST_TEST_UNREGISTER(config_general_core_metrics);
 
+	AST_TEST_UNREGISTER(bridge_to_string);
+
 	return 0;
 }
 
@@ -815,6 +881,8 @@ static int load_module(void)
 	AST_TEST_REGISTER(config_general_basic_auth);
 	AST_TEST_REGISTER(config_general_core_metrics);
 
+	AST_TEST_REGISTER(bridge_to_string);
+
 	ast_test_register_init(CATEGORY, &test_init_cb);
 	ast_test_register_cleanup(CATEGORY, &test_cleanup_cb);
 
